@@ -27,7 +27,7 @@ except ImportError:
 from errno import EAGAIN, ECONNRESET
 import os
 
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_HTTPServer.git"
 
 
@@ -174,7 +174,7 @@ class MIMEType:
 
 
 class HTTPResponse:
-    """Details of an HTTP response. Use in @`HTTPServer.route` decorator functions."""
+    """Details of an HTTP response. Use in `HTTPServer.route` decorator functions."""
 
     _HEADERS_FORMAT = (
         "HTTP/1.1 {}\r\n"
@@ -361,3 +361,25 @@ class HTTPServer:
                 # connection reset by peer, try again later.
                 return
             raise
+
+    @property
+    def request_buffer_size(self) -> int:
+        """
+        The maximum size of the incoming request buffer. If the default size isn't
+        adequate to handle your incoming data you can set this after creating the
+        server instance.
+
+        Default size is 1024 bytes.
+
+        Example::
+
+            server = HTTPServer(pool)
+            server.request_buffer_size = 2048
+
+            server.serve_forever(str(wifi.radio.ipv4_address))
+        """
+        return len(self._buffer)
+
+    @request_buffer_size.setter
+    def request_buffer_size(self, value: int) -> None:
+        self._buffer = bytearray(value)
